@@ -109,12 +109,48 @@ expand_term(Term, Pos0, [], Pos) :-
     atomic_pos(Pos0, Pos).
 expand_term(Term, Pos0, Expanded, Pos) :-
     b_setval('$term', Term),
+    prepare_directive(Term),
     '$def_modules'([term_expansion/4,term_expansion/2], MList),
     call_term_expansion(MList, Term, Pos0, Term1, Pos1),
     expand_terms(expand_term_2, Term1, Pos1, Term2, Pos),
     rename(Term2, Expanded),
     b_setval('$term', []).
 
+%!  prepare_directive(+Directive) is det.
+%
+%   Try to autoload goals associated with a   directive such that we can
+%   allow for term expansion of autoloaded directives such as setting/4.
+%   Trying to do so shall raise no errors  nor fail as the directive may
+%   be further expanded.
+
+prepare_directive((:- Directive)) :-
+    '$current_source_module'(M),
+    prepare_directive(Directive, M),
+    !.
+prepare_directive(_).
+
+prepare_directive(Goal, _) :-
+    \+ callable(Goal),
+    !.
+prepare_directive((A,B), Module) :-
+    !,
+    prepare_directive(A, Module),
+    prepare_directive(B, Module).
+prepare_directive(module(_,_), _) :- !.
+prepare_directive(Goal, Module) :-
+    '$get_predicate_attribute'(Module:Goal, defined, 1),
+    !.
+prepare_directive(Goal, Module) :-
+    \+ current_prolog_flag(autoload, false),
+    (   compound(Goal)
+    ->  compound_name_arity(Goal, Name, Arity)
+    ;   Name = Goal, Arity = 0
+    ),
+    '$autoload'(Module:Name/Arity),
+    !.
+prepare_directive(_, _).
+
+
 call_term_expansion([], Term, Pos, Term, Pos).
 call_term_expansion([M-Preds|T], Term0, Pos0, Term, Pos) :-
     current_prolog_flag(sandboxed_load, false),
@@ -144,13 +180,32 @@ call_term_expansion([M-Preds|T], Term0, Pos0, Term, Pos) :-
 expand_term_2((Head --> Body), Pos0, Expanded, Pos) :-
     dcg_translate_rule((Head --> Body), Pos0, Expanded0, Pos1),
     !,
-    expand_bodies(Expanded0, Pos1, Expanded, Pos).
+    expand_bodies(Expanded0, Pos1, Expanded1, Pos),
+    non_terminal_decl(Expanded1, Expanded).
 expand_term_2(Term0, Pos0, Term, Pos) :-
     nonvar(Term0),
     !,
     expand_bodies(Term0, Pos0, Term, Pos).
 expand_term_2(Term, Pos, Term, Pos).
 
+non_terminal_decl(Clause, Decl) :-
+    \+ current_prolog_flag(xref, true),
+    clause_head(Clause, Head),
+    '$current_source_module'(M),
+    (   '$get_predicate_attribute'(M:Head, non_terminal, NT)
+    ->  NT == 0
+    ;   true
+    ),
+    !,
+    '$pi_head'(PI, Head),
+    Decl = [:-(non_terminal(M:PI)), Clause].
+non_terminal_decl(Clause, Clause).
+
+clause_head(Head:-_, Head) :- !.
+clause_head(Head, Head).
+
+
+
 %!  expand_bodies(+Term, +Pos0, -Out, -Pos) is det.
 %
 %   Find the body terms in Term and   give them to expand_goal/2 for
@@ -316,6 +371,32 @@ isect3(=, H1, T1, _H2, T2, [H1|Int]) :-
 isect3(>, H1, T1,  _H2, T2, Int) :-
     isect2(T2, H1, T1, Int).
 
+%!  ord_subtract(+Set, +Subtract, -Diff)
+
+ord_subtract([], _Not, []).
+ord_subtract(S1, S2, Diff) :-
+    S1 == S2,
+    !,
+    Diff = [].
+ord_subtract([H1|T1], L2, Diff) :-
+    diff21(L2, H1, T1, Diff).
+
+diff21([], H1, T1, [H1|T1]).
+diff21([H2|T2], H1, T1, Diff) :-
+    compare(Order, H1, H2),
+    diff3(Order, H1, T1, H2, T2, Diff).
+
+diff12([], _H2, _T2, []).
+diff12([H1|T1], H2, T2, Diff) :-
+    compare(Order, H1, H2),
+    diff3(Order, H1, T1, H2, T2, Diff).
+
+diff3(<,  H1, T1,  H2, T2, [H1|Diff]) :-
+    diff12(T1, H2, T2, Diff).
+diff3(=, _H1, T1, _H2, T2, Diff) :-
+    oset_diff(T1, T2, Diff).
+diff3(>,  H1, T1, _H2, T2, Diff) :-
+    diff21(T2, H1, T1, Diff).
 
 %!  merge_variable_info(+Saved)
 %
@@ -396,8 +477,13 @@ prop_var(fresh(Fresh), Var) :-
     ;   Fresh = true
     ).
 prop_var(singleton(Singleton), Var) :-
-    get_attr(Var, '$var_info', Info),
-    get_dict(singleton, Info, Singleton).
+    nb_current('$term', Term),
+    term_singletons(Term, Singletons),
+    (   '$member'(V, Singletons),
+        V == Var
+    ->  Singleton = true
+    ;   Singleton = false
+    ).
 prop_var(name(Name), Var) :-
     (   nb_current('$variable_names', Bindings),
         '$member'(Name0=Var0, Bindings),
@@ -725,7 +811,6 @@ expand_meta_arg(N, A0, P0, true, A, P, M, MList, Term, Done) :-
     term_variables(A0, VL),
     remove_arg_pos(A3, PA2, M, VL, Ex, A, P).
 expand_meta_arg(^, A0, PA0, true, A, PA, M, MList, Term, Done) :-
-    replace_functions(A0, true, _, M),
     !,
     expand_setof_goal(A0, PA0, A, PA, M, MList, Term, Done).
 expand_meta_arg(S, A0, _PA0, Eval, A, _PA, M, _MList, _Term, _Done) :-
@@ -855,8 +940,24 @@ expand_setof_goal(M0:G, P0, M0:EG, P, M, MList, Term, Done) :-
 expand_setof_goal(G, P0, EG, P, M, MList, Term, Done) :-
     !,
     expand_goal(G, P0, EG0, P, M, MList, Term, Done),
-    compile_meta_call(EG0, EG, M, Term).            % TBD: Pos?
+    compile_meta_call(EG0, EG1, M, Term),
+    (   extend_existential(G, EG1, V)
+    ->  EG = V^EG1
+    ;   EG = EG1
+    ).
 
+%!  extend_existential(+G0, +G1, -V) is semidet.
+%
+%   Extend  the  variable  template  to    compensate  for  intermediate
+%   variables introduced during goal expansion   (notably for functional
+%   notation).
+
+extend_existential(G0, G1, V) :-
+    term_variables(G0, GV0), sort(GV0, SV0),
+    term_variables(G1, GV1), sort(GV1, SV1),
+    ord_subtract(SV1, SV0, New),
+    New \== [],
+    V =.. [v|New].
 
 %!  call_goal_expansion(+ExpandModules,
 %!                      +Goal0, ?Pos0, -Goal, -Pos, +Done) is semidet.
