@@ -50,7 +50,7 @@
 :- autoload(library(apply),[maplist/2,maplist/3,maplist/4,maplist/5]).
 :- autoload(library(error),[must_be/2]).
 :- autoload(library(lists),[subtract/3,same_length/2]).
-:- autoload(library(option),[option/3]).
+:- autoload(library(option),[option/2, option/3]).
 :- autoload(library(ordsets), [ord_intersection/3]).
 :- autoload(library(debug), [debug/3, assertion/1]).
 
@@ -72,6 +72,12 @@
 :- predicate_options(concurrent/3, 3,
                      [ pass_to(system:thread_create/3, 3)
                      ]).
+:- predicate_options(concurrent_forall/3, 3,
+                     [ threads(nonneg)
+                     ]).
+:- predicate_options(concurrent_and/3, 3,
+                     [ threads(nonneg)
+                     ]).
 :- predicate_options(first_solution/3, 3,
                      [ on_fail(oneof([stop,continue])),
                        on_error(oneof([stop,continue])),
@@ -447,7 +453,7 @@ concurrent_and(Gen, Test, Options) :-
     jobs(Jobs, Options),
     MaxSize is Jobs*4,
     message_queue_create(JobQueue, [max_size(MaxSize)]),
-    message_queue_create(AnswerQueue),
+    message_queue_create(AnswerQueue, [max_size(MaxSize)]),
     ca_template(Gen, Test, Templ),
     term_variables(Gen+Test, AllVars),
     ReplyTempl =.. [v|AllVars],
