@@ -213,6 +213,9 @@
 
 #define MSG_THREAD_WAIT		 350
 
+#define MSG_TRANSACTION		 360
+#define MSG_COMMIT		 361
+
 #define CHK_SECURE              1000
 #define CHK_HIGH_ARITY          1001
 #define CHK_HIGHER_ADDRESS      1002
