@@ -35,6 +35,7 @@
 */
 
 #include "pl-incl.h"
+#include "pl-comp.h"
 #include "pl-event.h"
 #include "pl-dbref.h"
 #include "pl-copyterm.h"
@@ -623,7 +624,8 @@ out:
 
 
 int
-predicate_update_event(Definition def, atom_t action, Clause cl ARG_LD)
+predicate_update_event(Definition def, atom_t action, Clause cl,
+		       unsigned flags ARG_LD)
 { wakeup_state wstate;
   term_t av;
   int rc = TRUE;
@@ -634,6 +636,9 @@ predicate_update_event(Definition def, atom_t action, Clause cl ARG_LD)
   if ( !PL_put_atom(av+1, action) ||
        !PL_put_clref(av+2, cl) )
     return FALSE;
+  if ( (flags&P_EVENT_ROLLBACK)	&&
+       !PL_cons_functor(av+1, FUNCTOR_rollback1, av+1) )
+    return FALSE;
 
   rc = call_event_list(def->events, 2, av PASS_LD);
 
