@@ -817,9 +817,8 @@ writeString(term_t t, write_options *options)
   PL_chars_t txt;
   int rc = TRUE;
 
+  PL_STRINGS_MARK();
   PL_get_text(t, &txt, CVT_STRING);
-  if ( txt.storage != PL_CHARS_LOCAL )
-    PL_save_text(&txt, BUF_MALLOC);
 
   if ( true(options, PL_WRT_QUOTED) )
   { int quote;
@@ -851,6 +850,7 @@ writeString(term_t t, write_options *options)
 	break;
     }
   }
+  PL_STRINGS_RELEASE();
 
 out:
   PL_free_text(&txt);
